package de.intevation.gnv.state.describedata;

/**
 * This interface describes some methods to set and retrieve a min-max value
 * pair with a specific name.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface MinMaxDescribeData extends DescribeData {

    /**
     * Returns the min value stored in this object.
     *
     * @return the min value.
     */
    public Object getMinValue();

    /**
     * Returns the max value stored in this object.
     *
     * @return the max value.
     */
    public Object getMaxValue();

    /**
     * Sets the min value in this object.
     *
     * @param minValue A new min value.
     */
    public void setMinValue(Object minValue);

    /**
     * Sets the max value in this object.
     *
     * @param maxValue A new max value.
     */
    public void setMaxValue(Object maxValue);

    /**
     * Returns the general name of this object.
     *
     * @return the name.
     */
    public String getName();

    /**
     * Returns the name of the min value.
     *
     * @return the name of the min value.
     */
    public String getMinName();

    /**
     * Returns the name of this max value.
     *
     * @return the name of the max value.
     */
    public String getMaxName();

    /**
     * Returns the state this object belongs to.
     *
     * @return the state.
     */
    public String getState();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
